CoppError

Enum CoppError 

pub enum CoppError {
    IoError(Error),
    ConstraintError(ConstraintError),
    PathError(PathError),
    RobotDynamicsError(RobotDynamicsError),
    Infeasible(String, String),
    Unbounded(String, String),
    InvalidInput(String, String),
    InvalidOptions(String, String),
    ClarabelSolverError(String, SolverError),
    ClarabelSolverStatus(String, SolverStatus),
    Other(String, String),
}
The error type for COPP.

Variants



IoError(Error)

Some error occurred in filesystem I/O operations, such as opening/creating log files.



ConstraintError(ConstraintError)

Some error occurred in the Constraint struct, such as invalid input or computation failure.



PathError(PathError)

Some error occurred in the Path struct, such as invalid input or computation failure.



RobotDynamicsError(RobotDynamicsError)

Some error occurred while evaluating user-provided robot inverse dynamics.



Infeasible(String, String)

The specified optimization problem is reported infeasible by the backend solver.



Unbounded(String, String)

The specified optimization problem is reported unbounded by the backend solver.



InvalidInput(String, String)

The solver/backend rejects the given model or data as invalid input.



InvalidOptions(String, String)

The solver/backend rejects the provided configuration options.



ClarabelSolverError(String, SolverError)

The Clarabel solver returned a concrete internal solver error.



ClarabelSolverStatus(String, SolverStatus)

The Clarabel solver terminated with a non-success status.



Other(String, String)

A backend-specific or uncategorized runtime error is reported.