#[repr(u8)]pub enum Verbosity {
Silent = 0,
Summary = 1,
Debug = 2,
Trace = 3,
}Expand description
Variants
Silent = 0
No log will be emitted.
Summary = 1
Only summary information will be emitted, including:
- The beginning and end of each algorithm.
- The total computation time of each algorithm.
- The success or failure of each algorithm.
Debug = 2
Detailed debug information will be emitted, including:
- The failure or degeneration of each algorithm at each grid point.
Trace = 3
Very detailed trace information will be emitted, including:
- The values of reachable sets, optimal profiles, and other intermediate variables at each step of each algorithm.