pub enum VerbosityOutput {
Println,
Log,
File(String),
}Expand description
Output backend used by verbosity logging.
Default is Println to preserve current behavior.
Variants
Println
Emit messages with println!.
Typical usage:
use copp::diag::{VerbosityOutput, set_verbosity_output};
set_verbosity_output(VerbosityOutput::Println)?;Log
Emit messages through the log facade (info/debug/trace).
Before selecting this mode, initialize a global logger in your app/test.
Typical usage:
use log::LevelFilter;
use std::sync::Once;
use copp::diag::{VerbosityOutput, set_verbosity_output};
static INIT: Once = Once::new();
INIT.call_once(|| {
let _ = env_logger::Builder::new()
.filter_level(LevelFilter::Info)
.is_test(true)
.try_init();
});
set_verbosity_output(VerbosityOutput::Log)?;File(String)
Emit messages to a configured log file.
Typical usage:
use copp::diag::{VerbosityOutput, set_verbosity_output};
// Auto-creates parent directories and opens file in append mode.
set_verbosity_output(VerbosityOutput::File("logs/copp/run.log".into()))?;Trait Implementations
Sourceimpl Clone for VerbosityOutput
impl Clone for VerbosityOutput
Sourcefn clone(&self) -> VerbosityOutput
fn clone(&self) -> VerbosityOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerbosityOutput
impl Debug for VerbosityOutput
Sourceimpl Default for VerbosityOutput
impl Default for VerbosityOutput
Sourcefn default() -> VerbosityOutput
fn default() -> VerbosityOutput
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for VerbosityOutput
impl PartialEq for VerbosityOutput
impl Eq for VerbosityOutput
impl StructuralPartialEq for VerbosityOutput