pub struct ReachSet2Options { /* private fields */ }Expand description
The options for reach_set2.
Implementations
Sourceimpl ReachSet2Options
impl ReachSet2Options
Sourcepub fn lp_feas_tol(&self) -> f64
pub fn lp_feas_tol(&self) -> f64
Return the LP feasibility tolerance used by reachability subproblems.
Sourcepub fn a_cmp_abs_tol(&self) -> f64
pub fn a_cmp_abs_tol(&self) -> f64
Return the absolute tolerance used for comparing a bounds.
Sourcepub fn a_cmp_rel_tol(&self) -> f64
pub fn a_cmp_rel_tol(&self) -> f64
Return the relative tolerance used for comparing a bounds.