ReachSet2OptionsBuilder

Struct ReachSet2OptionsBuilder 

pub struct ReachSet2OptionsBuilder {
    pub lp_feas_tol: f64,
    pub a_cmp_abs_tol: f64,
    pub a_cmp_rel_tol: f64,
    pub verbosity: Verbosity,
}
Builder for ReachSet2Options.

Fields

lp_feas_tol: f64

Feasibility tolerance used by LP subproblems in reachable-set computation.

a_cmp_abs_tol: f64

Absolute tolerance for comparing interval bounds a_max and a_min.

a_cmp_rel_tol: f64

Relative tolerance for comparing interval bounds a_max and a_min.

verbosity: Verbosity

Verbosity level for diagnostics during reachability analysis.

Implementations

Source

impl ReachSet2OptionsBuilder

pub fn new() -> Self

Create a new ReachSet2OptionsBuilder with default values.

pub fn lp_feas_tol(self, tol: f64) -> Self

Set the tolerance for checking the feasibility of the linear program.
The default value is 1E-8.

pub fn a_cmp_abs_tol(self, tol: f64) -> Self

Set the absolute tolerance for comparing a_max and a_min to determine whether the reachable set is empty (a_max < a_min) or degenerated (a_max == a_min).
Let tol = max(a_cmp_abs_tol, a_cmp_rel_tol * max(|a_max|, |a_min|)).

  • If a_max < a_min - tol, then the reachable set is empty.
  • If a_max > a_min + tol, then the reachable set is non-degenerated.
  • Otherwise, the reachable set is degenerated into a single point.

The default value is 1E-8.

pub fn a_cmp_rel_tol(self, tol: f64) -> Self

Set the relative tolerance for comparing a_max and a_min. More details refer to a_cmp_abs_tol. The default value is 1E-8.

pub fn verbosity(self, verbosity: Verbosity) -> Self

Set the verbosity level for logging. More details refer to Verbosity.
The default value is Verbosity::Silent.

pub fn build(self) -> Result<ReachSet2Options, CoppError>

Build the ReachSet2Options from the builder where the validity of the options is checked.

pub fn validate(&self) -> Result<(), CoppError>

This function checks the validity of the options and returns an error if any option is invalid.