topp3_lp

Function topp3_lp 

pub fn topp3_lp(
    problem: &Topp3Problem<'_>,
    options: &ClarabelOptions,
) -> Result<Topp3Profile, CoppError>
Strict TOPP3-LP API for production use.

Purpose

Use this entry when caller only needs a valid Topp3Profile and treats non-accepted solver statuses as hard failures.

Contract

  • Internally calls topp3_lp_expert.
  • Returns Ok(Topp3Profile { .. }) iff options.is_allow(solution.status) is true.
  • Returns Err(CoppError::ClarabelSolverStatus(...)) when status is not accepted.

Returns

Returns accepted TOPP3 profile.

Errors

Returns CoppError on model/solver failures and non-accepted solver status.

More details are provided in the documentation of topp3_lp_expert.