topp3_socp

Function topp3_socp 

pub fn topp3_socp(
    problem: &Topp3Problem<'_>,
    options: &ClarabelOptions,
) -> Result<Topp3Profile, CoppError>
Strict TOPP3-SOCP API for production use.

Purpose

Use this entry when caller only needs a valid Topp3Profile and treats non-accepted solver statuses as hard failures.

Contract

  • Internally calls topp3_socp_expert.
  • Returns Ok(Topp3Profile { .. }) iff options.is_allow(solution.status) is true.
  • Returns Err(CoppError::ClarabelSolverStatus(...)) when status is not accepted.

Returns

Returns accepted TOPP3 profile.

Errors

Returns CoppError on conic-model/solver failures and non-accepted solver status.

More details are provided in the documentation of topp3_socp_expert.