pub trait RobotTorque: RobotBasic {
// Required method
fn inverse_dynamics(
&self,
q: &[f64],
dq: &[f64],
ddq: &[f64],
tau: &mut [f64],
);
}Expand description
Robot trait with inverse-dynamics capability.
This trait is mainly required when building COPP2/COPP3 problems with
torque/dynamics constraints. For TOPP-only use cases, a direct
Constraints workflow is usually
enough.
A usize variable can serve as a trivial RobotTorque implementation representing a point-mass model, where tau = ddq. For physical robots, users should implement this trait with their own inverse dynamics.