Copp3Problem

Struct Copp3Problem 

pub struct Copp3Problem<'a, M: RobotTorque> { /* private fields */ }
The problem of COPP3.

Arguments

  • robot - A robot with torque implemented, which defines the constraints and dynamic of the problem.
  • objectives - Objectives for COPP3 optimization.
  • idx_s_start - The starting index along the path (reached).
  • a_linearization - Linearization reference profile for third-order constraints.
  • a_boundary=(a_start,a_final) - The initial and final acceleration at the start and end of the path.
  • b_boundary=(b_start,b_final) - The initial and final boundary conditions for b.
  • num_stationary=(start,end) - Effective stationary intervals derived in build_with_linearization().

Implementations

Source

impl<'a, M: RobotTorque> Copp3Problem<'a, M>

pub fn set_a_linearization(&mut self, a_linearization: &'a [f64])

Update linearization profile.

pub fn set_a_linear(&mut self, a_linearization: &'a [f64])

Backward-compatible alias for set_a_linearization.

pub fn set_objective(&mut self, objective: &'a [CoppObjective<'a>])

Update objective list.

pub fn as_topp3_problem(&self) -> Topp3Problem<'_>

Convert to the TOPP3 view that shares interval/boundary/linearization fields.